pydhcp
-------
Simple Python DHCP Library. DHCP Packet-Parsing/Client/Server

### Installation

```
pip install pydhcp3
```

### Examples

Examples can be found in the [examples](https://github.com/imgurbot12/pydhcp/tree/master/examples) directory.
